Changelog
=========


0.2.1 (2018-05-07)
------------------
- Merge pull request #3 from shosca/transaction. [Serkan Hosca]
- Add transaction tests. [Serkan Hosca]
- Merge pull request #2 from shosca/proxy. [Serkan Hosca]
- Refactor scoped session proxy. [Serkan Hosca]
- Merge pull request #1 from shosca/field-mapping. [Serkan Hosca]
- More field mapping coverage. [Serkan Hosca]


0.2.0 (2018-05-07)
------------------

Fix
~~~
- Model choice field iterator. [Serkan Hosca]

Other
~~~~~
- 0.2.0. [Serkan Hosca]
- Increase test coverage. [Serkan Hosca]
- Increase test coverage. [Serkan Hosca]


0.1.1 (2018-05-05)
------------------
- Fix meta test. [Serkan Hosca]


0.1.0 (2018-05-05)
------------------
- Initial commit. [Serkan Hosca]
